@@ -3,7 +3,12 @@ import logging
 from the_spymaster_util import wrap
 from the_spymaster_util.http_client import BaseHttpClient
 
-from .structs import GenerateGuessRequest, GenerateHintRequest, GenerateGuessResponse, GenerateHintResponse
+from .structs import (
+    GenerateGuessRequest,
+    GenerateGuessResponse,
+    GenerateHintRequest,
+    GenerateHintResponse,
+)
 
 log = logging.getLogger(__name__)
 DEFAULT_BASE_URL = "http://localhost:5000"
